@@ -578,7 +578,6 @@ class SettingsDialog(QDialog):
         Constructor
         """
         QDialog.__init__(self, parent)
-        #self.resize(800, 450)
         self.setWindowTitle("Settings")
         self.saveButton = QPushButton("Save",  self)
         accountLabel = QLabel("YouTube accounts")
@@ -632,7 +631,62 @@ class SettingsDialog(QDialog):
         self.downloadFormatButton.setPickSelector(self.downloadFormatSelector)
         downloadFormat = VideoDownloadSettings.downloadFormat
         self.downloadFormatSelector.setCurrentIndex(VideoDownloadSettings.formatList.index(downloadFormat))
-        searchesLabel = QLabel("Youtube searches")
+        categoriesLabel = QLabel("YouTube categories")
+        categoriesLabel.setStyleSheet("color: rgb(120, 120, 120)")
+        self.categoryDict = {u'All': u'', u'Films - Drama': u'_Movies_Drama', u'Entertainment': u'_Entertainment', 
+                            u'Science & Technology': u'_Tech', u'Films - Comedy': u'_Movies_Comedy', 
+                            u'Films - Documentary': u'_Movies_Documentary', u'News & Politics': u'_News', 
+                            u'Pets & Animals': u'_Animals', u'Non-profits & Activism': u'_Nonprofit', 
+                            u'Music': u'_Music', u'Films - Shorts': u'_Movies_Shorts', u'Trailers': u'_Trailers', 
+                            u'Films': u'_Movies', u'Videoblogging': u'_Videoblog', u'Films - Horror': u'_Movies_Horror', 
+                            u'Comedy': u'_Comedy', u'Howto & Style': u'_Howto', u'Shows': u'_Shows', u'Gaming': u'_Games', 
+                            u'People & Blogs': u'_People', u'Education': u'_Education', u'Films - Thriller': u'_Movies_Thriller', 
+                            u'Films - Classics': u'_Movies_Classics', u'Travel & Events': u'_Travel', u'Films - Foreign': u'_Movies_Foreign', 
+                            u'Short Films': u'_Shortmov', u'Films - Sci-Fi/Fantasy': u'_Movies_Sci_fi_fantasy', u'Cars & Vehicles': u'_Autos', 
+                            u'Films - Family': u'Movies_Family', u'Films - Action/Adventure': u'Movies_Action_adventure', 
+                            u'Films - Anime/Animation': u'_Movies_Anime_animation', u'Sport': u'_Sports', u'Film & Animation': u'_Film'
+                            }
+        self.categoryModel = QStandardItemModel(0, 1)
+        self.categorySelector = QMaemo5ListPickSelector()
+        self.categorySelector.setModel(self.categoryModel)
+        categoryKeys = self.categoryDict.keys()
+        categoryKeys.sort()
+        num = 0
+        for category in categoryKeys:
+            item = QStandardItem(category)
+            item.setEditable(False)
+            item.setTextAlignment(Qt.AlignCenter)
+            self.categoryModel.appendRow(item)
+            if self.categoryDict.get(category) == YouTubeAPISettings.categoryFilter:
+                self.categorySelector.setCurrentIndex(num) 
+            num += 1
+        self.categoryButton = QMaemo5ValueButton("Most recent/Most viewed category filter", self)
+        self.categoryButton.setValueLayout(QMaemo5ValueButton.ValueUnderText)
+        self.categoryButton.setPickSelector(self.categorySelector)
+        self.locationDict = {'All': '', 'Australia': 'AU/', 'Brazil': 'BR/', 'Canada': 'CA/', 'Czech Republic': 'CZ/', 
+                            'France': 'FR/', 'Germany': 'DE/', 'Great Britain': 'GB/', 'Holland': 'NL/', 'Hong Kong': 'HK/', 
+                            'India': 'IN/', 'Ireland': 'IE/', 'Israel': 'IL/', 'Italy': 'IT/', 'Japan': 'JP/', 'Mexico': 'MX/', 
+                            'New Zealand': 'NZ/', 'Poland': 'PL/', 'Russia': 'RU/', 'South Korea': 'KR/', 'Spain': 'ES/', 
+                            'Sweden': 'SE/', 'Taiwan': 'TW/', 'United States': 'US/'
+                            }
+        self.locationModel = QStandardItemModel(0, 1)
+        self.locationSelector = QMaemo5ListPickSelector()
+        self.locationSelector.setModel(self.locationModel)
+        locationKeys = self.locationDict.keys()
+        locationKeys.sort()
+        num = 0
+        for location in locationKeys:
+            item = QStandardItem(location)
+            item.setEditable(False)
+            item.setTextAlignment(Qt.AlignCenter)
+            self.locationModel.appendRow(item)
+            if self.locationDict.get(location) == YouTubeAPISettings.locationFilter:
+                self.locationSelector.setCurrentIndex(num)
+            num += 1
+        self.locationButton = QMaemo5ValueButton("Most recent/Most viewed location filter", self)
+        self.locationButton.setValueLayout(QMaemo5ValueButton.ValueUnderText)
+        self.locationButton.setPickSelector(self.locationSelector)
+        searchesLabel = QLabel("YouTube searches")
         searchesLabel.setStyleSheet("color: rgb(120, 120, 120)")
         self.clearSearchesButton = QPushButton("Clear recent searches", self)
         generalLabel = QLabel("General settings")
@@ -666,6 +720,9 @@ class SettingsDialog(QDialog):
         vBox.addWidget(self.downloadFolderButton)
         vBox.addWidget(self.downloadFormatButton)
         vBox.addWidget(self.downloadStatusCheckBox)
+        vBox.addWidget(categoriesLabel)
+        vBox.addWidget(self.categoryButton)
+        vBox.addWidget(self.locationButton)
         vBox.addWidget(searchesLabel)
         vBox.addWidget(self.clearSearchesButton)
         vBox.addWidget(generalLabel)
@@ -722,7 +779,11 @@ class SettingsDialog(QDialog):
         downloadFolder = unicode(self.downloadFolderButton.valueText())
         playbackFormat = self.playbackFormatSelector.currentIndex()
         downloadFormat = self.downloadFormatSelector.currentIndex()
-        YouTubeAPISettings.defaultUser = account
+        category = unicode(self.categoryButton.valueText())
+        location = unicode(self.locationButton.valueText())
+        YouTubeAPISettings.defaultUser = account        
+        YouTubeAPISettings.categoryFilter = self.categoryDict.get(category)
+        YouTubeAPISettings.locationFilter = self.locationDict.get(location)
         VideoPlaybackSettings.playbackFormat = VideoPlaybackSettings.formatList[playbackFormat]
         VideoDownloadSettings.downloadFormat = VideoDownloadSettings.formatList[downloadFormat]
         VideoDownloadSettings.downloadFolder = downloadFolder
